@@ -128,7 +128,7 @@ class PDF(Resource):
         # get the pdf as an array of bytes
         buffer = pdf.output(dest='S')
         # send the pdf with name .pdf
-        filename = f"{article.publish_date}_{article.title}.{article.config._language}.pdf"
+        # filename = f"{article.publish_date}_{article.title}.{article.config._language}.pdf"
         # https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Common_types
         # https://gist.github.com/Miserlou/fcf0e9410364d98a853cb7ff42efd35a
         with tempfile.NamedTemporaryFile() as fo:
@@ -138,6 +138,7 @@ class PDF(Resource):
             return send_file(
                 io.BytesIO(fo.read()),
                 attachment_filename=fo.name,
+                as_attachment=True,
                 mimetype='application/octet-stream'
             )
 
